Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2563)

Unified Diff: runtime/vm/stub_code_mips.cc

Issue 2719603002: Rename Closure instance field type_arguments_ to instantiator_. (Closed)
Patch Set: work in progress Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/stub_code_ia32.cc ('k') | runtime/vm/stub_code_x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code_mips.cc
diff --git a/runtime/vm/stub_code_mips.cc b/runtime/vm/stub_code_mips.cc
index d93cb8bd5d3184c10894ff8c0bed53b24e9e2c67..c2336441e835d7c98ba0e7849099b79800e93605 100644
--- a/runtime/vm/stub_code_mips.cc
+++ b/runtime/vm/stub_code_mips.cc
@@ -1882,11 +1882,12 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
Label loop, found, not_found, next_iteration;
// T0: instance class id.
// T1: instance type arguments.
// T2: Entry start.
// T7: null.
__ SmiTag(T0);
__ BranchNotEqual(T0, Immediate(Smi::RawValue(kClosureCid)), &loop);
+ __ lw(T1, FieldAddress(A0, Closure::instantiator_offset()));
__ lw(T0, FieldAddress(A0, Closure::function_offset()));
// T0: instance class id as Smi or function.
__ Bind(&loop);
@@ -1882,11 +1882,12 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) {
Label loop, found, not_found, next_iteration;
// T0: instance class id.
- // T1: instance type arguments.
+ // T1: instance type arguments (still null if closure).
// T2: Entry start.
// T7: null.
« no previous file with comments | « runtime/vm/stub_code_ia32.cc ('k') | runtime/vm/stub_code_x64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698